MoPubRewardedVideoAd class

Constructors

MoPubRewardedVideoAd(String adUnitId, void listener(RewardedVideoAdResult, dynamic), {bool reloadOnClosed = false})

Properties

adUnitId → String
final
hashCode → int
The hash code for this object.
no setterinherited
listener → void Function(RewardedVideoAdResult, dynamic)
final
reloadOnClosed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isReady() → Future<bool?>
load() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited